aboutsummaryrefslogtreecommitdiff
path: root/src/tool_cfgable.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/tool_cfgable.h')
-rw-r--r--src/tool_cfgable.h2
1 files changed, 1 insertions, 1 deletions
diff --git a/src/tool_cfgable.h b/src/tool_cfgable.h
index 96618f8b1..3bd908879 100644
--- a/src/tool_cfgable.h
+++ b/src/tool_cfgable.h
@@ -100,7 +100,7 @@ struct OperationConfig {
bool use_ascii; /* select ascii or text transfer */
bool autoreferer; /* automatically set referer */
bool failonerror; /* fail on (HTTP) errors */
- bool include_headers; /* send headers to data output */
+ bool show_headers; /* show headers to data output */
bool no_body; /* don't get the body */
bool dirlistonly; /* only get the FTP dir list */
bool followlocation; /* follow http redirects */